@@ -6,14 +6,12 @@ installable python package, but so long as the number of rules remain
 low, it makes sense to keep it bundled with SQLFluff core.
 """
 
-from typing import List, Type
-
 from sqlfluff.core.plugin import hookimpl
 from sqlfluff.core.rules import BaseRule
 
 
 @hookimpl
-def get_rules() -> List[Type[BaseRule]]:
+def get_rules() -> list[type[BaseRule]]:
     """Get plugin rules.
 
     NOTE: Rules are imported only on fetch to manage import times
