@@ -75,3 +75,23 @@ ALTER TABLE `foo` ADD COLUMN d INT AS (a*abs(b));
 ALTER TABLE `foo` ADD COLUMN e TEXT AS (substr(c,b,b+1)) STORED;
 
 ALTER TABLE `foo` CONVERT TO CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
+
+ALTER TABLE `foo` CONVERT TO CHARACTER SET `utf8mb4` COLLATE `utf8mb4_unicode_ci`;
+
+ALTER TABLE `foo` CONVERT TO CHARACTER SET 'utf8mb4' COLLATE 'utf8mb4_unicode_ci';
+
+ALTER TABLE `foo` CONVERT TO CHARACTER SET "utf8mb4" COLLATE "utf8mb4_unicode_ci";
+
+ALTER TABLE CUST TRUNCATE PARTITION data_dt;
+
+ALTER TABLE `foo` ADD COLUMN geo GEOMETRY NOT NULL SRID 4326;
+
+ALTER TABLE my_table MODIFY num INT SIGNED NOT NULL;
+
+ALTER TABLE my_table MODIFY num INT UNSIGNED NOT NULL;
+
+ALTER TABLE my_table MODIFY num INT ZEROFILL NOT NULL;
+
+ALTER TABLE my_table MODIFY num INT UNSIGNED ZEROFILL NOT NULL;
+
+ALTER TABLE my_table MODIFY num INT ZEROFILL UNSIGNED NOT NULL;
