@@ -103,6 +103,26 @@ SELECT
 FROM people
 GROUP BY cube(name, age);
 
+-- CUBE within GROUP BY clause with single clause on newline
+SELECT
+    name,
+    count(*) AS record_count
+FROM people
+GROUP BY cube(
+    name
+);
+
+-- CUBE within GROUP BY clause with multiple clauses on newline
+SELECT
+    name,
+    age,
+    count(*) AS record_count
+FROM people
+GROUP BY cube(
+    name,
+    age
+);
+
 -- ROLLUP within GROUP BY clause
 SELECT
     name,
