@@ -13,3 +13,9 @@ END CATCH
 GO
 
 THROW 50005, N'an error occurred', 1;
+
+BEGIN TRY
+    EXEC spSomeProc
+END TRY
+BEGIN CATCH
+END CATCH;
